# CHANGELOG



## v0.1.0 (2023-11-23)

### Chore

* chore: add github actions ([`ceb80f2`](https://github.com/eaglelab-zju/EGC/commit/ceb80f26d8ad146c998d645a1620ad3b93859480))

* chore: remove useless files ([`936f177`](https://github.com/eaglelab-zju/EGC/commit/936f1770e76a18a6234c2e65b7e5030077501be5))

* chore: update install scripts, requirements and README ([`0f39453`](https://github.com/eaglelab-zju/EGC/commit/0f394539f9d14ae4c5335781aa84d22201b4d4b9))

* chore: update venv installation scripts ([`11b7686`](https://github.com/eaglelab-zju/EGC/commit/11b7686e053227247675c10de609e3221f32bbc3))

* chore: update env install scripts ([`98c221d`](https://github.com/eaglelab-zju/EGC/commit/98c221d1b73911ffb60868329583e6ae433bb5ce))

* chore: add cu113 requirements and conda env yml ([`cd5e6ef`](https://github.com/eaglelab-zju/EGC/commit/cd5e6ef94763ced38d3af8121f11ae78f31c1c3c))

* chore: update environ vars for cuda &gt; 10.2 ([`dbbfccb`](https://github.com/eaglelab-zju/EGC/commit/dbbfccbd6ff5b5040462f68a3d38400f12f9bb3b))

* chore: add neighborhood pattern and homophily analysis nb ([`7ff608d`](https://github.com/eaglelab-zju/EGC/commit/7ff608d559dca5813c2bd2ecd916d9d893595b41))

* chore: update gitignore ([`d625ace`](https://github.com/eaglelab-zju/EGC/commit/d625ace7dbf064be18f3206c5d26bf14d23fcee7))

* chore: update README and requirements ([`6b780fe`](https://github.com/eaglelab-zju/EGC/commit/6b780fed557476161b2bdcb45ff5a72a37f5f632))

* chore: add vscode extension recommendations ([`8e97670`](https://github.com/eaglelab-zju/EGC/commit/8e976704ccf2208f3a249290de99e6400f9731e8))

* chore: format some code ([`385055a`](https://github.com/eaglelab-zju/EGC/commit/385055a2db05acc7b11d50d458400e163512693e))

* chore: update DGL dependency to 0.8 ([`cb990f3`](https://github.com/eaglelab-zju/EGC/commit/cb990f37438e7fce688f28e51a55eef7e64602ab))

* chore: add VGAECD overall results and reorganize the directory ([`18742e4`](https://github.com/eaglelab-zju/EGC/commit/18742e4ae90b80b5cd1cd6a8fb67c332430a69d3))

* chore: upate README and comment ([`761fd37`](https://github.com/eaglelab-zju/EGC/commit/761fd37252784abeade980d1835ee6e852ad617b))

* chore: update environment config ([`faba65c`](https://github.com/eaglelab-zju/EGC/commit/faba65c4ac71a4113def53fcd899fcc6b922e8cc))

* chore: add md format, disable no-member and no-name-in-module for pre-commit ([`1d805d2`](https://github.com/eaglelab-zju/EGC/commit/1d805d26a39ae0afccb13764172ff0020dde766a))

* chore: update requirements ([`57857ec`](https://github.com/eaglelab-zju/EGC/commit/57857ec364c2062400e4f9dfebab3fc2a6ddb3c6))

* chore: format all files ([`f1e64b3`](https://github.com/eaglelab-zju/EGC/commit/f1e64b382ee5b7455b57c4f01b8f3f29d8edcb86))

* chore: add lint, formatter and env ([`0203a4a`](https://github.com/eaglelab-zju/EGC/commit/0203a4a58580457ee5b361c02b389a134cf5d748))

### Documentation

* docs: update README torch version ([`d1fcfb6`](https://github.com/eaglelab-zju/EGC/commit/d1fcfb6d0e580b4a3311f04ab6ab3218979cc273))

### Feature

* feat: add SGC Kmeans ([`19da95b`](https://github.com/eaglelab-zju/EGC/commit/19da95b0bfc0a89f49661091e1f77f01584e4fb4))

* feat: add base model for deep graph clustering with structure learning ([`d38c788`](https://github.com/eaglelab-zju/EGC/commit/d38c78890f2ce532c1656d5720851d94b75a30ae))

* feat: add identity activation for multilayer gnn and dnn ([`d429991`](https://github.com/eaglelab-zju/EGC/commit/d429991e92c761395af5bcbc0314ab6c843567e2))

* feat: add log parser ([`4f1456f`](https://github.com/eaglelab-zju/EGC/commit/4f1456f35bbf4b52ed2f01264e88730bd3e364b2))

* feat: add SUBLIME model ([`f5355cb`](https://github.com/eaglelab-zju/EGC/commit/f5355cbb01fa65fe6e89a07e66da85281dfcd66c))

* feat: add betweenness experiments ([`cf60855`](https://github.com/eaglelab-zju/EGC/commit/cf6085588cbc8c48b1d17a253ff59cf08f49eeb2))

* feat: add GDCL ([`0bff027`](https://github.com/eaglelab-zju/EGC/commit/0bff0270e2b1c55b7920861188e3355bad020c4d))

* feat: add dump and load utils for var saving ([`50ad1d1`](https://github.com/eaglelab-zju/EGC/commit/50ad1d113378e9926ac144cc716d36310b81a5a8))

* feat: add homophily analysis scripts ([`2c311a5`](https://github.com/eaglelab-zju/EGC/commit/2c311a5eeeebdd550e2e558e7eb5881e22cbe580))

* feat: add datasets BlogCatalog, Flickr and ACM with subprocess cmd util ([`a20f5bb`](https://github.com/eaglelab-zju/EGC/commit/a20f5bb91251b6253203396b2297561249f6211a))

* feat: add pretrain model:MVGRL ([`26333e0`](https://github.com/eaglelab-zju/EGC/commit/26333e0bc391294e45c5e625e60e0428e78bbb50))

* feat: add dglAug ([`7889dab`](https://github.com/eaglelab-zju/EGC/commit/7889dab9f474f785f3386e80fadedc85ab5285e8))

* feat(ClusterNet): add clusterNet model ([`41844ef`](https://github.com/eaglelab-zju/EGC/commit/41844efd52b13537512216d8065e4b8690025b52))

* feat(module): enable dataloader to customize the number of neighbor samples ([`6110853`](https://github.com/eaglelab-zju/EGC/commit/6110853d6b7b93547042372ca8cb06b203d70f3b))

* feat(DGI): enable batch training ([`af8d163`](https://github.com/eaglelab-zju/EGC/commit/af8d163d72239d1b2af731256496f2ec5d623155))

* feat(model): add IDEC ([`7878a6e`](https://github.com/eaglelab-zju/EGC/commit/7878a6e1911666f291ed6c57099244042eb109d8))

* feat(module): add multilayer GraphSAGE ([`99405a0`](https://github.com/eaglelab-zju/EGC/commit/99405a031768fa9b56a8c3ee2e8156a2e88f2038))

* feat(*): add modules to save and load model, update device selection for cc, dgi, aug ([`4adb868`](https://github.com/eaglelab-zju/EGC/commit/4adb868963a4d457ae039855594c45af39ff59a0))

* feat(model): add Contrastive Clustering ([`eeedbe8`](https://github.com/eaglelab-zju/EGC/commit/eeedbe84f57d62d35000b70d032bdbdbf7fe5b96))

* feat: add naive_data_loader ([`c74258c`](https://github.com/eaglelab-zju/EGC/commit/c74258ccae8e01baebaf0bfec9e8484ff096f8f7))

* feat: add graph augmentations and contrastive DGI_kmeans ([`dcf12d2`](https://github.com/eaglelab-zju/EGC/commit/dcf12d2ca6e3c2eaf2850844b82288cf75be7c6c))

* feat: add spectral clustering utils ([`8b5eccc`](https://github.com/eaglelab-zju/EGC/commit/8b5eccc6d2326d6ceeb474252f78bfd8fa43075e))

* feat: add category statistics scripts ([`11f9d41`](https://github.com/eaglelab-zju/EGC/commit/11f9d41ccd94ce0235c4cb2569ba2c882195bf64))

* feat: add label count ([`abf242e`](https://github.com/eaglelab-zju/EGC/commit/abf242e6875d51c1de79a1486abb95035d378bdd))

* feat: add batch-test bash script ([`d88d5ad`](https://github.com/eaglelab-zju/EGC/commit/d88d5add442471ae219d0675dc92384e352199e0))

* feat: add statistical script ([`f1bc369`](https://github.com/eaglelab-zju/EGC/commit/f1bc369c605f0a9bf8fb8417ae04dcbb401f73fd))

* feat: add CommunityGAN ([`ca9cc20`](https://github.com/eaglelab-zju/EGC/commit/ca9cc205d83e9e744ae07c467663e9956f2f8c30))

* feat: add VGAECD ([`31e592b`](https://github.com/eaglelab-zju/EGC/commit/31e592b50f9cef8a1692d5c23b33b74d3432ad23))

* feat: vgae based on local implement gcn ([`df09e51`](https://github.com/eaglelab-zju/EGC/commit/df09e518255237400683d5f5f476a4e8fac12ea6))

* feat: add DGI node embedding and DGI kmeans community detection model ([`b627367`](https://github.com/eaglelab-zju/EGC/commit/b6273679affa4291f12898b172d4783064b16ac1))

* feat: add GMI node embedding and GMI kmeans community detection model ([`08ec2ec`](https://github.com/eaglelab-zju/EGC/commit/08ec2ec6eb5b17178bb941f047d676fc1fd50b44))

* feat: add MNMF ([`8b398a3`](https://github.com/eaglelab-zju/EGC/commit/8b398a3e98b3fea74db5bf509e1091e727ff80d4))

* feat: add DANMF ([`651af73`](https://github.com/eaglelab-zju/EGC/commit/651af73f7131d67228f3ad8feadd363fb1a1ad8f))

### Fix

* fix: auto rm wrong cython version output ([`8a58fc9`](https://github.com/eaglelab-zju/EGC/commit/8a58fc9c16e9989dc2ce9992d0f13b4cf26d7b74))

* fix: update dgl version ([`ade82ff`](https://github.com/eaglelab-zju/EGC/commit/ade82ff09b9554b4539b76ab37d45e9f014ece0d))

* fix: update AGCN,vgae,exp scripts ([`ab8a6a3`](https://github.com/eaglelab-zju/EGC/commit/ab8a6a30f8adc52ee3087c5aa0cbc36a3f156421))

* fix: update exp scripts 10 runs ([`75c9da8`](https://github.com/eaglelab-zju/EGC/commit/75c9da8fbb8f476156bb06d97ad1ed3027d0e68a))

* fix: add CoraFull ([`9ad98e2`](https://github.com/eaglelab-zju/EGC/commit/9ad98e25099e4c1b8961e5a31029814e1b277daf))

* fix(daegc): remove loss early stop and same as raw code ([`8e8460b`](https://github.com/eaglelab-zju/EGC/commit/8e8460b6148eff396c79e68a3004754ad3d11deb))

* fix: update SEComm,dfcn,subline ([`9ec239b`](https://github.com/eaglelab-zju/EGC/commit/9ec239b69d2d1b96cd54b60092496c9cc06dac53))

* fix: update exp scripts ([`68b0cfe`](https://github.com/eaglelab-zju/EGC/commit/68b0cfe319532747a3c0c84b112c894fa8d08673))

* fix(DAEGC): update ([`aa88b9a`](https://github.com/eaglelab-zju/EGC/commit/aa88b9acc3a2b505302cbf2b0cc233addd718e2b))

* fix(SEComm): print info bug ([`90de375`](https://github.com/eaglelab-zju/EGC/commit/90de375fd66b82d7cb28b01a7fec1e3bd33d6c63))

* fix: structure learned not used ([`c8bb987`](https://github.com/eaglelab-zju/EGC/commit/c8bb98725a0caaad8ea79212c2e40d0a2ee1b796))

* fix: fix aug_types for data_loader ([`41725a5`](https://github.com/eaglelab-zju/EGC/commit/41725a5c6bbc86fb63b61410a6b9fe2a1d022d59))

* fix: update add edge exp results ([`e2993dd`](https://github.com/eaglelab-zju/EGC/commit/e2993dd0873c1449fd17bcb53b7f57ae7772cef9))

* fix(exp): add gae add edge exp ([`8d1ee60`](https://github.com/eaglelab-zju/EGC/commit/8d1ee603d103a1562428e9729e9b97728bb163de))

* fix: add softmax to multilayer dnn ([`f704fce`](https://github.com/eaglelab-zju/EGC/commit/f704fce2d4d3fc51df521ed7180c116d9e92e849))

* fix(exp): add random edges exp ([`1f526da`](https://github.com/eaglelab-zju/EGC/commit/1f526da48bedd763c512eb80b65c0977be60dc61))

* fix: update train file ([`23ed667`](https://github.com/eaglelab-zju/EGC/commit/23ed6671b7e7779b6a7a4b01c914bc8529b1d08a))

* fix: update exp results ([`899bfdb`](https://github.com/eaglelab-zju/EGC/commit/899bfdbc3964efdc73a26cc68955d606bf5e6234))

* fix(SEComm): add self loop in layers ([`148aee7`](https://github.com/eaglelab-zju/EGC/commit/148aee74c8f57a3893c41fc615d154ff3247b811))

* fix: some bugs in sdcn and mvgrl ([`577f7d6`](https://github.com/eaglelab-zju/EGC/commit/577f7d6a3cd08c7af83ad732efe921bf98c85c83))

* fix(AGE): default config cora params ([`a39f22d`](https://github.com/eaglelab-zju/EGC/commit/a39f22d1f6bc7502e1c909a2e6281ca7e5f86403))

* fix: update exp scripts ([`b1aa279`](https://github.com/eaglelab-zju/EGC/commit/b1aa279346a3f59519b06b0134fb32ea8b20bf7e))

* fix(SENet): not same device bugs ([`bdfbda8`](https://github.com/eaglelab-zju/EGC/commit/bdfbda8c987663f8b8aad8d1a92ddbfb5f3ba13c))

* fix: add three exp scripts ([`9b46fc0`](https://github.com/eaglelab-zju/EGC/commit/9b46fc07596bdae9000f99386a20ff54ac1c4bb9))

* fix(gala): set some var to cuda ([`10f592e`](https://github.com/eaglelab-zju/EGC/commit/10f592ea45eb7f5e6cdb79e583de507f8cdea194))

* fix(SEComm): move add self loop to train ([`289df67`](https://github.com/eaglelab-zju/EGC/commit/289df67b41863500baab29cc69fe8327088375ec))

* fix(agcn): some bugs ([`5e32e52`](https://github.com/eaglelab-zju/EGC/commit/5e32e5269128dcc4a52a53450d094327de51fbeb))

* fix: add self loop to some models ([`104751d`](https://github.com/eaglelab-zju/EGC/commit/104751dc10ccfea716e6940c12fb101f58ede4af))

* fix(gdcl): have bug ([`b793517`](https://github.com/eaglelab-zju/EGC/commit/b79351723a6031d7e9689ae408134e34fe6da239))

* fix: update epx ([`da085b0`](https://github.com/eaglelab-zju/EGC/commit/da085b0435d3b7808e41395bcd4fd4f06083b1e1))

* fix(mvgrl): not load model ([`e09a7d5`](https://github.com/eaglelab-zju/EGC/commit/e09a7d5b835823988576343960a2f7e53b4d61e7))

* fix: VGAE loss BUG ([`d27d29f`](https://github.com/eaglelab-zju/EGC/commit/d27d29f7b133cc150b06e09497511d525cd4a5d7))

* fix: update betweenness_exp ([`0cb6a19`](https://github.com/eaglelab-zju/EGC/commit/0cb6a19681dcccbe5aad1e110500d5d40b34020c))

* fix: augs none bugs ([`779ee89`](https://github.com/eaglelab-zju/EGC/commit/779ee8976a4d71a3b81b083b348b914e92dc82db))

* fix: some bugs ([`1da0e5b`](https://github.com/eaglelab-zju/EGC/commit/1da0e5b6933fe0a95cb01e05cfeea89c1fe11cbf))

* fix(mvgrl): add mvgrl to train.py ([`f67af7b`](https://github.com/eaglelab-zju/EGC/commit/f67af7be28636fa574a27d9b77ab9c72b0df8323))

* fix(GDCL): update GDCL ([`5826b36`](https://github.com/eaglelab-zju/EGC/commit/5826b3657f57dbb5fdf36fa429f52eae270162b7))

* fix(mvgrl): update docstring ([`3f9c878`](https://github.com/eaglelab-zju/EGC/commit/3f9c878ca62dbc4cebe945afd35815525e6f00a7))

* fix(mvgrl): use common normalization ([`29ca92b`](https://github.com/eaglelab-zju/EGC/commit/29ca92b23b3126c4c18a7bed61bb8f8534a956b6))

* fix: updata datasets ([`4bb90f6`](https://github.com/eaglelab-zju/EGC/commit/4bb90f6349283833adca12b5bfce8fa95c605b0f))

* fix: updata load data ([`2275c89`](https://github.com/eaglelab-zju/EGC/commit/2275c898df84dcd5dd295e5b9e74fecc9cc59cfa))

* fix: update requirments ([`c156631`](https://github.com/eaglelab-zju/EGC/commit/c1566316e7ccb7166b876168fd5661bebc5929d7))

* fix: update dataset ([`1e26ac4`](https://github.com/eaglelab-zju/EGC/commit/1e26ac403794ed92b07a70fe4b0c72cafe4242d6))

* fix: add install to README ([`682afc5`](https://github.com/eaglelab-zju/EGC/commit/682afc5ba071cae97152049acdfe6672bb4c0340))

* fix(mvgrl): move mvgrl to node embedding ([`fc0403f`](https://github.com/eaglelab-zju/EGC/commit/fc0403fe0e220a22356f3e4efc1ee48c6f8e7795))

* fix: move dataload to utils ([`2e87d21`](https://github.com/eaglelab-zju/EGC/commit/2e87d2173682cbda3f0c7acfa40903c91f50d619))

* fix: update graph_augmentation ([`92f3f07`](https://github.com/eaglelab-zju/EGC/commit/92f3f0794dbab41e2c32b1ecc3a7ab2397ce8766))

* fix: rename util name and some small fix ([`a62a742`](https://github.com/eaglelab-zju/EGC/commit/a62a7429ed755e138afb8c3d765521d20ceb170d))

* fix: move dglAug to module ([`95d6ceb`](https://github.com/eaglelab-zju/EGC/commit/95d6ceb1f0cc0e747aaa2ae272c57e1eb32e3e4a))

* fix(mvgrl): update bugs ([`c5c9909`](https://github.com/eaglelab-zju/EGC/commit/c5c99095298717978688083e595079d0bcd89a27))

* fix(cc): aug types ([`a90aa2e`](https://github.com/eaglelab-zju/EGC/commit/a90aa2e14f6354ac91a991e52a456a7c96e4fb2a))

* fix: print dataset info for several datasets when loading ([`b7ebc19`](https://github.com/eaglelab-zju/EGC/commit/b7ebc194697a5d98f3405df43d9a47f6babcd49a))

* fix: update mask col ([`f31ed52`](https://github.com/eaglelab-zju/EGC/commit/f31ed52ff94be7ce2c83b845232fe334c4dcc3d5))

* fix: dgl.seed should not occupy cuda:0 when other gpu is set ([`cf51757`](https://github.com/eaglelab-zju/EGC/commit/cf517579e31e249c24bd61ff68e0a54c2939915a))

* fix: should not transfer models into cuda in init func ([`45d246f`](https://github.com/eaglelab-zju/EGC/commit/45d246f40541a4ae877899012bde6d420cbace45))

* fix(daegc): merge ([`42eee54`](https://github.com/eaglelab-zju/EGC/commit/42eee545c3409a72d8e33b08eafa3e3144e366e8))

* fix(daegc): update daegc using adj_csr ([`f593865`](https://github.com/eaglelab-zju/EGC/commit/f593865afcaaff11678f27428b9add564809e87d))

* fix: pca_kmeans args update ([`eb43c80`](https://github.com/eaglelab-zju/EGC/commit/eb43c80a8550f153bbd383622887ec117efb7462))

* fix(ComE): remove unneccessary file from git and update requirements ([`b5459b1`](https://github.com/eaglelab-zju/EGC/commit/b5459b18e074f735569d8899536b8ffcb7825dec))

* fix(CC): add parameter initialization and feature normalization to cc ([`0d3e253`](https://github.com/eaglelab-zju/EGC/commit/0d3e2538c82336755fdee40e950b3529c19b8f5e))

* fix(DGI): remove contrastive dgi ([`d0265a0`](https://github.com/eaglelab-zju/EGC/commit/d0265a0e81f13d2f25958dae067c4b752417e38f))

* fix(CC): add feature normalization to CC ([`7d64e9a`](https://github.com/eaglelab-zju/EGC/commit/7d64e9a5685586f66fb73e3a600ad1a3e3acdffe))

* fix(*): update graph augmentation, gpu args setting and some other small fixes ([`1b2f346`](https://github.com/eaglelab-zju/EGC/commit/1b2f346347bd170ac4fc7255c93dc1aad52c354e))

* fix(utils): force evaluation func to reshape label array ([`88fb3cb`](https://github.com/eaglelab-zju/EGC/commit/88fb3cba8bd9e1c5d99b724be9ad745e30e3b02d))

* fix: use csr adj instead of dense adj in case of large graphs ([`65776fe`](https://github.com/eaglelab-zju/EGC/commit/65776fe0fbaf48d79a0616292052c0ae544c0260))

* fix(IDEC): make clustering centers trainable ([`3d1943d`](https://github.com/eaglelab-zju/EGC/commit/3d1943d91ab06b8072ad2a8ea3ae361f3be04bf4))

* fix: update argparse to use yaml config ([`fcd554a`](https://github.com/eaglelab-zju/EGC/commit/fcd554ad9ac3e44d4f5b93ae67de30dd585968c1))

* fix: support graph augmentations for large graphs and update contrastive dgi ([`b3c5929`](https://github.com/eaglelab-zju/EGC/commit/b3c5929e5e5c9c74f8501429a6b60af2ab4fdcc7))

* fix: update argparse to use yaml config ([`348bdbd`](https://github.com/eaglelab-zju/EGC/commit/348bdbd9db8a2a730d7c7034be4ff355047cf709))

* fix: move set seed to the beginning of train.py ([`96cd791`](https://github.com/eaglelab-zju/EGC/commit/96cd7919b3b6c4ea9384173e289b4cd905027af0))

* fix: not set seed for DANMF ([`515eda5`](https://github.com/eaglelab-zju/EGC/commit/515eda5d28ece2c6cc8a866cebe3f568e140e978))

* fix: update argparser ([`d6824a9`](https://github.com/eaglelab-zju/EGC/commit/d6824a9828a07183b9b1c17df12ed2a7aeeeaa1a))

* fix: vgaecd p_z_c overflow ([`6bf6047`](https://github.com/eaglelab-zju/EGC/commit/6bf60475c71bea63c81c608f4c9d76cce7f497f6))

* fix: add optional global argument not_set_seed ([`c6aa7e1`](https://github.com/eaglelab-zju/EGC/commit/c6aa7e1b0787dd1f8adde5f32b94886cd81e2ccb))

* fix: allow customize gcn layer num for gmi, fix gmi shuffle and yapf ([`2a6c7a8`](https://github.com/eaglelab-zju/EGC/commit/2a6c7a8b3fe3f95b013222a6a3523a4ed397dabc))

* fix: add res and change normalize method of adj for SENet ([`08f0750`](https://github.com/eaglelab-zju/EGC/commit/08f07500ca2a414171f107a7551e6ecc4e9b92a7))

* fix: separate args of different models with subparsers ([`21b258f`](https://github.com/eaglelab-zju/EGC/commit/21b258fb81e22c0fe5897233dc52fdd1a4f688f5))

* fix: lost imports, typo and env update ([`81c297d`](https://github.com/eaglelab-zju/EGC/commit/81c297d50153fd57d5fcc5d92fb6acf6c0b74a6b))

### Refactor

* refactor: BREAK CHANGE, change dir structures ([`996849a`](https://github.com/eaglelab-zju/EGC/commit/996849a7bd14f772e868e81389248effece44b0b))

### Style

* style: format code ([`1774bc6`](https://github.com/eaglelab-zju/EGC/commit/1774bc67f5462e8d1059e08dabccfc1136febf7f))

* style: format SENet code ([`c5aaaff`](https://github.com/eaglelab-zju/EGC/commit/c5aaaffd16b30976644110b495a63d1c41d970fe))

### Unknown

* Merge branch &#39;master&#39; of github.com:EagleLab-ZJU/EagleCommunityDetection ([`f3846b7`](https://github.com/eaglelab-zju/EGC/commit/f3846b7a5de32532a3972ee3be7d54a1b3a92289))

* Merge branch &#39;master&#39; of zjuygm.github.com:EagleLab-ZJU/EagleCommunityDetection ([`b08d0e5`](https://github.com/eaglelab-zju/EGC/commit/b08d0e59bd05f760d53aefa802b0b756c7744060))

* Merge branch &#39;master&#39; of github.com:EagleLab-ZJU/EagleCommunityDetection ([`d3c70fd`](https://github.com/eaglelab-zju/EGC/commit/d3c70fd328ea0597916cafe351efafcd510abd58))

* Merge branch &#39;master&#39; of zjuygm.github.com:EagleLab-ZJU/EagleCommunityDetection ([`e38bfed`](https://github.com/eaglelab-zju/EGC/commit/e38bfed6edb65b04f49e425410476b1662b10ec2))

* Merge branch &#39;master&#39; of zjuygm.github.com:EagleLab-ZJU/EagleCommunityDetection ([`30ca400`](https://github.com/eaglelab-zju/EGC/commit/30ca400f9d5d9aa6797d045c393db6b518df2e8d))

* Merge branch &#39;master&#39; of zjuygm.github.com:EagleLab-ZJU/EagleCommunityDetection ([`13791c6`](https://github.com/eaglelab-zju/EGC/commit/13791c6d408fd78435172286b8b41ca97433853e))

* Merge branch &#39;master&#39; of github.com:zhoushengisnoob/EagleCommunityDetection ([`013105f`](https://github.com/eaglelab-zju/EGC/commit/013105facb1e9d65dd26bd910bfc72b45a021df0))

* doc: update docs ([`2fe1738`](https://github.com/eaglelab-zju/EGC/commit/2fe17385443b8da72bd3ab3a8c6794afc79a875a))

* Add the function to automatically initialize the ComE environment ([`ae0267f`](https://github.com/eaglelab-zju/EGC/commit/ae0267f4f29bdbac6fe6a15413360b6d4922e1d9))

* update GALA, change model parameters to configuration file ([`f13675a`](https://github.com/eaglelab-zju/EGC/commit/f13675ad6e03ca84b8baf2ae27d96e0b062a5f35))

* Merge branch &#39;master&#39; of https://github.com/zhoushengisnoob/EagleCommunityDetection ([`e9f7b0d`](https://github.com/eaglelab-zju/EGC/commit/e9f7b0db868f898d8ed429081b17a04f1d3659ee))

* fix:SEComm bug ([`70c8c47`](https://github.com/eaglelab-zju/EGC/commit/70c8c478ff1cd990aaeb4a5a2a1020775ef01a4e))

* fix:pre-commit ([`8cfd211`](https://github.com/eaglelab-zju/EGC/commit/8cfd21128035db75570c08d35d49a9c7ca4b7749))

* feat:add SEComm model ([`57f30ae`](https://github.com/eaglelab-zju/EGC/commit/57f30aee7098323762d77a153aff6d47ddf334de))

* fix:bug ([`baa5c20`](https://github.com/eaglelab-zju/EGC/commit/baa5c20c4d928cf48753734d57fdc089929992e9))

* Merge branch &#39;master&#39; of https://github.com/zhoushengisnoob/EagleCommunityDetection ([`b834da6`](https://github.com/eaglelab-zju/EGC/commit/b834da64c36f4cd21e91ac57730926d268a23013))

* fix:DAEGC kmeans bug ([`afd34b8`](https://github.com/eaglelab-zju/EGC/commit/afd34b86e7af67f603290bdca0da603cc8f40933))

* add model AGC and GALA,but there are some bugs in gala ([`96bb114`](https://github.com/eaglelab-zju/EGC/commit/96bb1140ac70bfed964908e0edf0f0ae0bdb1da2))

* add AGC and GALA,but there are some bugs in GALA ([`3f441c6`](https://github.com/eaglelab-zju/EGC/commit/3f441c63ad885f5f4b5003cb7a6ef5c50f89134b))

* fix:update readme ([`4a1e611`](https://github.com/eaglelab-zju/EGC/commit/4a1e611473f17372f7d16a51ebb91335b86f7c4c))

* feat:add DAEGC model ([`56bb83e`](https://github.com/eaglelab-zju/EGC/commit/56bb83eec632c61578ce50d7059883b9a1282078))

* fix:update AGE output to Tensor and fix other bugs ([`8880669`](https://github.com/eaglelab-zju/EGC/commit/88806691ca525b95d2a35713c0db80f8212137e0))

* add model AGCN and format code ([`8e51df5`](https://github.com/eaglelab-zju/EGC/commit/8e51df56d2cc87d6e5f615683b076764cae22617))

* Merge branch &#39;master&#39; of github.com:zhoushengisnoob/EagleCommunityDetection
add AGCN ([`9c2b7d8`](https://github.com/eaglelab-zju/EGC/commit/9c2b7d8df88383dbfc3c53ce5b99ef546aa570e1))

* add model AGCN and format code ([`132d252`](https://github.com/eaglelab-zju/EGC/commit/132d2525e7f4a415011b74f34580234b62451bcf))

* update ComE ([`395d470`](https://github.com/eaglelab-zju/EGC/commit/395d470aaba80c9e0c225dd9b212cd33be72474e))

* exp1227 ([`a9febb7`](https://github.com/eaglelab-zju/EGC/commit/a9febb74bb79bb95787f10b7319eba9290c304c3))

* fix:add AGE code comment ([`5a6b09d`](https://github.com/eaglelab-zju/EGC/commit/5a6b09d9eecce3e6e28acceefc1fb15032c1fd66))

* 1225 ([`63be8b1`](https://github.com/eaglelab-zju/EGC/commit/63be8b130178504ebeb47cd678f9b2d37f828dcc))

* feat:add AGE cluster ([`b0a3873`](https://github.com/eaglelab-zju/EGC/commit/b0a3873e1fa7117b21a8ddd92219558c9216dce7))

* update ComE ([`ed3f2c1`](https://github.com/eaglelab-zju/EGC/commit/ed3f2c15e1dcc0cff807d4e10d6e50f37edbd6ce))

* add model of ComE ([`20b5c65`](https://github.com/eaglelab-zju/EGC/commit/20b5c65bcc8834a0db3bf9f75b7846feff780bca))

* fix:update run sh ([`a65b8a2`](https://github.com/eaglelab-zju/EGC/commit/a65b8a2cf8166cc059ed1a4dbe31368b5dd5c028))

* update run_test_zh.sh ([`dcad832`](https://github.com/eaglelab-zju/EGC/commit/dcad832495073b6882a65fdbc935bd20569b20e9))

* 1214exp ([`fef660c`](https://github.com/eaglelab-zju/EGC/commit/fef660c6c0a4b333791929e88b3af0ae30538f21))

* fix:update run_test_zh.sh ([`92f52d6`](https://github.com/eaglelab-zju/EGC/commit/92f52d6f2c058cf0abb735214f1dba2ccfeecb6e))

* feat:add run_test_ygm.sh ([`24773bf`](https://github.com/eaglelab-zju/EGC/commit/24773bf7fc51acd665f7d69d2a420e498a4bff6c))

* update my test scripts ([`a524e11`](https://github.com/eaglelab-zju/EGC/commit/a524e11dc91bf837e574ca24fa369d4332c97151))

* Merge branch &#39;master&#39; of zjuygm.github.com:zhoushengisnoob/EagleCommunityDetection ([`975aed3`](https://github.com/eaglelab-zju/EGC/commit/975aed34ef4deb74a898e99410417ee44eddedd1))

* fix:update gae,vgae,dfcn print info and early stop ([`a4801b3`](https://github.com/eaglelab-zju/EGC/commit/a4801b3080189747678b33548655e57e22f7e4a6))

* add run_test_zh.sh ([`4765e0d`](https://github.com/eaglelab-zju/EGC/commit/4765e0d993a1da3bfd6da81182cfc5ef155a0d55))

* change the model of SDCN use cuda ([`59866e9`](https://github.com/eaglelab-zju/EGC/commit/59866e9d043c3601fef4a546e6b52f7034188d46))

* add experiments mode ([`f2974db`](https://github.com/eaglelab-zju/EGC/commit/f2974db7339b041f7b89924290a5b20efcb4ad0e))

* debug sdcn ([`2371b66`](https://github.com/eaglelab-zju/EGC/commit/2371b66ea6a6f8b4412696abd6e8502bddcac29f))

* fix:resolve readme latex error ([`4984ee0`](https://github.com/eaglelab-zju/EGC/commit/4984ee09686d705504332bec51a11ea9807b4bb7))

* fix:implement igae using dgl and update DFCN ([`d3b14e6`](https://github.com/eaglelab-zju/EGC/commit/d3b14e681545ddbd93e74ac7b7a59a3898d24dad))

* fix:add common AE to DFCN ([`5f3530e`](https://github.com/eaglelab-zju/EGC/commit/5f3530eda8ca56db1e12b1cba5612d2dd9525807))

* fix:update gae fit and add DGL_GAEKmeans ([`c180e06`](https://github.com/eaglelab-zju/EGC/commit/c180e06a61515a854d02c7cafaecf822e3e2f135))

* fix:update vgae fit and add DGL_VGAEKmeans ([`8ffd1c1`](https://github.com/eaglelab-zju/EGC/commit/8ffd1c150fb8a1297c029a19711c6c980aa4ffa5))

* merge:refactor gae and vage using dgl ([`cf11912`](https://github.com/eaglelab-zju/EGC/commit/cf119121bb9d05c65b80b0e9ae998875cdd82653))

* refactor:gae and vgae move to node embedding ([`fefe46f`](https://github.com/eaglelab-zju/EGC/commit/fefe46f9c0d6467ea358ba0dc41a849cd37c56bc))

* format SDCN ([`80831ce`](https://github.com/eaglelab-zju/EGC/commit/80831ce0c73da529b549a2081330b73317fd90fc))

* refactor:Decoupling dfcn ([`fee348c`](https://github.com/eaglelab-zju/EGC/commit/fee348c45451bef4a337f43471f348e40330148f))

* Merge branch &#39;master&#39; of github.com:zhoushengisnoob/EagleCommunityDetection ([`de76ed7`](https://github.com/eaglelab-zju/EGC/commit/de76ed7e1a06f8f8d01c629e68cf3b52ac397ecd))

* Merge branch &#39;master&#39; of zjuygm.github.com:zhoushengisnoob/EagleCommunityDetection
fix:vgae ([`1a35382`](https://github.com/eaglelab-zju/EGC/commit/1a353820950d8e76f07bdaae220aca8fc820b898))

* fix:vgae ([`1317b0f`](https://github.com/eaglelab-zju/EGC/commit/1317b0f3332b4528a8b7ae3d46713c3a9e58a9bf))

* feat:add dfcn model ([`a58449b`](https://github.com/eaglelab-zju/EGC/commit/a58449beebb487e26152df5f484a0a88c0ac9a22))

* add SNEet model ([`616aab2`](https://github.com/eaglelab-zju/EGC/commit/616aab220774499e05947aa6ca743afe5e1e3fa3))

* update README ([`193109e`](https://github.com/eaglelab-zju/EGC/commit/193109e65fcdbcee3b11009950e8ea49eb8ee6d3))

* Merge pull request #4 from galogm/feat/add-DANMF

Feat/add danmf ([`d64baa4`](https://github.com/eaglelab-zju/EGC/commit/d64baa485b53ef283599944bc32f304f238a8de8))

* Merge pull request #1 from zhoushengisnoob/feat/add-lint-formatter

Feat/add lint formatter ([`2219349`](https://github.com/eaglelab-zju/EGC/commit/221934990421c3f839b9a4995d6bddf4282674e6))

* modify ([`8544d1e`](https://github.com/eaglelab-zju/EGC/commit/8544d1eb727f9977f16012e74bb66b434a6906b9))

* modify SDCN ([`e316f5b`](https://github.com/eaglelab-zju/EGC/commit/e316f5bd4cec28bea30ee0b3e110dde153fa5d13))

* modify SDCN ([`091f7d1`](https://github.com/eaglelab-zju/EGC/commit/091f7d1f15e6c6b611b356b91a6c69167fde2149))

* modify ([`9cccf13`](https://github.com/eaglelab-zju/EGC/commit/9cccf139937f15a561c22ece6afaf6ae21f455b5))

* modify ([`d0160a5`](https://github.com/eaglelab-zju/EGC/commit/d0160a5ff370cfa34d1ba74caf53a8b6c6aff312))

* modify ([`97605ba`](https://github.com/eaglelab-zju/EGC/commit/97605ba28b865bab711c12f76961f6f09cc92812))

* test ([`292634c`](https://github.com/eaglelab-zju/EGC/commit/292634c799eeac86f3efd5b2ff4d49dc05d56277))

* modify ([`372d7c8`](https://github.com/eaglelab-zju/EGC/commit/372d7c80cec3fd192e62beb32779c77c29cf316a))

* modify ([`aaee7b1`](https://github.com/eaglelab-zju/EGC/commit/aaee7b1abaf20086db8b35292881f01b9edee472))

* modify ([`828c595`](https://github.com/eaglelab-zju/EGC/commit/828c595e3efd983d3c6fe0ab717c145766e69812))

* modify ([`8bbc487`](https://github.com/eaglelab-zju/EGC/commit/8bbc4876d8595f008837236aafe3cf79af5f59a9))

* modify ([`fb8e1a3`](https://github.com/eaglelab-zju/EGC/commit/fb8e1a343739e53f171049500b75cf4a8ae63606))

* modify the code structure of sdcn ([`0617f26`](https://github.com/eaglelab-zju/EGC/commit/0617f26a999889619166a8e8b3d36e385eec345a))

* modify the structure of sdcn, add some specific paremters for sdcn ([`9bfa732`](https://github.com/eaglelab-zju/EGC/commit/9bfa7322f66e323aa6e2f38c9cfaad99a3ed12fa))

* update SDCN ([`dcf103d`](https://github.com/eaglelab-zju/EGC/commit/dcf103d0b3a53fdce542b502f09a876606ffb05c))

* merge:gae and vgae ([`7c50580`](https://github.com/eaglelab-zju/EGC/commit/7c505809f4af570ef2b4d8bec5481a4e6aa41a8f))

* add gae and vgae module ([`b1bade5`](https://github.com/eaglelab-zju/EGC/commit/b1bade5fe6b75d03f2310a9d3dd0aaf631ab3a63))

* delete some redundant file ([`150323b`](https://github.com/eaglelab-zju/EGC/commit/150323b2e4dcf68d06acb81c101c7820a8ad6aaa))

* add the model of sdcn ([`7414bbc`](https://github.com/eaglelab-zju/EGC/commit/7414bbc8d291dbc376021ac59048e8a57013b129))

* add the model of sdcn ([`4e5fc91`](https://github.com/eaglelab-zju/EGC/commit/4e5fc9119f0fdc3125ea38e8b32d26a0aeb6b4ff))

* confirm final dataset ([`66747a6`](https://github.com/eaglelab-zju/EGC/commit/66747a626d03dfdf80e09b51a88e5dca31b4c737))

* u ([`105f88d`](https://github.com/eaglelab-zju/EGC/commit/105f88dc96e5a2e5b1d119e4833a711800daa280))

* addding example ([`dce4234`](https://github.com/eaglelab-zju/EGC/commit/dce42346d7b0077218667b944adeb251329d4da2))

* Complete framework for pca_kmeans ([`14b5095`](https://github.com/eaglelab-zju/EGC/commit/14b509580bc1106580f72a5753982c44f5d51939))

* update dataset ([`25cebf7`](https://github.com/eaglelab-zju/EGC/commit/25cebf7ccfb225936d0d7b4a3268b3aefd5d132b))

* add data ([`a5940c6`](https://github.com/eaglelab-zju/EGC/commit/a5940c6c0998e3000d0285273a19150ecaaf1a5a))

* Initial commit ([`5782422`](https://github.com/eaglelab-zju/EGC/commit/57824220172bfac22c70e63c014b245f0066bc3c))
